==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/hu.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Nyilvános hivatkozás",
    "Photos" : "Fényképek",
    "On This Day" : "Ezen a napon",
    "Your memories under your control" : "Az Ön emlékei, az Ön felügyelete alatt",
    "All media" : "Összes média",
    "Videos" : "Videók",
    "Albums" : "Albumok",
    "Collaborative albums" : "Közreműködőkkel készült albumok",
    "People" : "Emberek",
    "Folders" : "Mappák",
    "Favorites" : "Kedvencek",
    "On this day" : "A mai napon",
    "Shared with you" : "Megosztva Önnel",
    "Tags" : "Címkék",
    "Places" : "Helyek",
    "Map" : "Térkép",
    "Photos settings" : "Fényképek beállításai",
    "Mark selection as favorite" : "Kiválasztás megjelölése kedvencként",
    "Add selection to favorites" : "Kiválasztás hozzáadása a kedvencekhez",
    "Remove selection from favorites" : "Kiválasztás eltávolítása a kedvencek közül",
    "Name of the album" : "Az album neve",
    "Location of the album" : "Az album helye",
    "Back" : "Vissza",
    "Add collaborators" : "Közreműködők hozzáadása",
    "Save" : "Mentés",
    "Create album" : "Album létrehozása",
    "Add to Album" : "Hozzáadás az albumhoz",
    "Add selection to album {albumName}" : "Kiválasztás hozzáadása a(z) {albumName} albumhoz",
    "Shared by" : "Megosztotta:",
    "Create a new album." : "Új album létrehozása.",
    "Create new album" : "Új album létrehozása",
    "New album" : "Új album",
    "_%n item_::_%n photos and videos_" : ["%n fénykép és videó","%n fénykép és videó"],
    "Failed to fetch collaborators list." : "A közreműködők lekérése sikertelen.",
    "Failed to update album." : "Az album frissítése sikertelen.",
    "Add people or groups who can edit your album" : "Emberek vagy csoportok hozzáadása, akik szerkeszthetik az albumot",
    "Search people or groups" : "Felhasználó vagy csoport keresése",
    "No recommendations. Start typing." : "Nincs javaslat. Kezdjen gépelni.",
    "Group" : "Csoport",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} eltávolítása a közreműködőktől",
    "Copy the public link" : "Nyilvános hivatkozás másolása",
    "Public link copied!" : "Nyilvános hivatkozás másolva.",
    "Copy public link" : "Nyilvános hivatkozás másolása",
    "Delete the public link" : "Nyilvános hivatkozás törlése",
    "Create public link share" : "Nyilvános hivatkozásos megosztás létrehozása",
    "Share via public link" : "Megosztva nyilvános hivatkozással",
    "This collection does not exist" : "Ez a gyűjtemény nem létezik",
    "An error occurred" : "Hiba történt",
    "No picture for this day" : "Nincs kép erre a napra",
    "Picture taken on this day will show up here." : "Ezen a napon a napon készült képek fognak itt megjelenni.",
    "More photos from this day" : "További képek erről a napról",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nem hozzárendelt fénykép","%n nem hozzárendelt fénykép"],
    "Favorite" : "Kedvenc",
    "Favorite image, open the full size \"{name}\" image" : "Kedvenc kép, a \"{name}\" kép teljes méretben való megnyitása",
    "Open the full size \"{name}\" image" : "A teljes méretű „{name}” fénykép megnyitása",
    "Select image {imageName}" : "{imageName} kép kiválasztása",
    "Open the \"{name}\" folder" : "A \"{name}\" könyvtár megnyitása",
    "Back to {folder}" : "Vissza ide: {folder}",
    "Go back" : "Visszalépés",
    "Share this folder" : "Mappa megosztása",
    "Dates" : "Dátumok",
    "Jump to specific date in list" : "Ugrás a listán egy megadott dátumhoz",
    "Jump to {date}" : "Ugrás ekorra {date}",
    "Add to {destination}" : "Hozzáadás ehhez: {destination}",
    "The destination folder is owned by {owner}" : "A célmappa {owner}tulajdonában van",
    "There are no photos or videos yet!" : "Még nincs fénykép vagy videó.",
    "_{years} year ago_::_{years} years ago_" : ["{years} éve","{years} éve"],
    "Enable squared photos view" : "A négyzet alakú fotónézet engedélyezése",
    "Delete source directory" : "A forrás könyvtár törlése",
    "Select a source folder for your media" : "Válaszd ki a könyvtárat a médiád számára",
    "All folders" : "Összes könyvtár",
    "Add a Photos source for the timelines" : "Fotó forrás hozzáadása az idővonalakhoz",
    "Add folder" : "Könyvtár hozzáadása",
    "Select the default upload location for your media" : "Válaszd ki a alapvető feltöltési helyet a médiáid számára",
    "Home" : "Kezdőlap",
    "Choose default Photos upload and Albums location" : "A Fényképfeltöltés és az Albumok alapértelmezett helyének kiválasztása",
    "Choose a different folder" : "Válassz másik könyvtárat",
    "View" : "Megtekintés",
    "Media folders" : "Média könyvtárak",
    "Choose the folders from where photos and videos are shown." : "Válassz egy könyvtárat ahonnan a fotók és videók megjelennek.",
    "Upload folder" : "Feltöltési könyvtár",
    "Choose the folder where photos and albums are uploaded to." : "Válassz másik könyvtárat a fotók és albumok feltöltése számára.",
    "_%n photo_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "Unselect all" : "Kijelölés megszüntetése",
    "Add photos to this album" : "Fényképek hozzáadása az albumhoz",
    "Manage collaborators for this album" : "Az album közreműködőinek kezelése",
    "Open actions menu" : "Műveletek menü megnyitása",
    "Edit album details" : "Album részleteinek szerkesztése",
    "Download all files in album" : "Összes fájl letöltése az albumből",
    "Delete album" : "Album törlése",
    "Download selected files" : "Kiválasztott fájlok letöltése",
    "Remove selection from album" : "Kiválasztás eltávolítása az albumból",
    "This album does not have any photos or videos yet!" : "Még nincs fénykép vagy videó ebben az albumban.",
    "Add photos to {albumName}" : "Fényképek hozzáadása a(z) {albumName} albumhoz",
    "Manage collaborators" : "Közreműködők kezelése",
    "Save collaborators for this album." : "Közreműködők mentése ehhez az albumhoz.",
    "Cover photo for album {albumName}" : "Borítókép a(z) „{albumName}” albumhoz",
    "There is no album yet!" : "Még nincs album.",
    "This person could not be found" : "Ez a személy nem található",
    "Rename person" : "Személy átnevezése",
    "Merge with different person" : "Összevonás egy másik személlyel",
    "Download selected photos" : "Kiválasztott fényképek letöltése",
    "Remove from favorites" : "Eltávolítás a kedvencek közül",
    "Remove person" : "Személy eltávolítása",
    "Name of this person" : "A személy neve",
    "Save." : "Mentés.",
    "Merge person" : "Személy egyesítése",
    "Move to different person" : "Áthelyezés egy másik személyhez",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Fénykép áthelyezése egy másik személyhez","Fényképek áthelyezése egy másik személyhez"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fénykép eltávolítása a személytől","Fényképek eltávolítása a személytől"],
    "This might take some time depending on the size of your photo library." : "Ez a fényképkönyvtár méretétől függően eltarthat egy darabig.",
    "Recognized people will show up here" : "A felismert emberek itt fognak megjelenni",
    "This folder does not exist" : "Ez a mappa nem létezik",
    "Loading folders …" : "Mappák betöltése…",
    "No photos in here" : "Itt nincsenek fényképek",
    "Taken on {date} at {time}" : "Fényképezve {date}-án {time}-kor",
    "This place does not have any photos or videos yet!" : "Ehhez a helyhez még nincs fénykép vagy videó.",
    "Add photos to this place" : "Fényképek hozzáadása ehhez a helyhez",
    "Cover photo for place {placeName}" : "A következő hely borítóképe: {placeName}",
    "There is no place yet!" : "Még nincsenek helyek.",
    "Cover photo for shared album {albumName}." : "Borítókép a(z) „{albumName}” megosztott albumhoz.",
    "Back to tags overview" : "Vissza a címkeáttekintőhöz",
    "No photos with this tag yet" : "Még nincsenek fényképek ezzel a címkével",
    "No tags yet" : "Még nincsenek címkék",
    "Photos with tags will show up here" : "A címkével rendelkező fényképek itt fognak megjelenni",
    "Popular tags" : "Népszerű címkék",
    "All tags" : "Összes jelölés",
    "One of the source folders does not exist" : "Az egyik forrás könyvtár nem létezik",
    "Add to album" : "Hozzáadás az albumhoz",
    "Delete selection" : "Kiválasztás törlése",
    "No photos or videos in here" : "Itt nincs fénykép vagy videó",
    "Unassigned faces" : "Nem hozzárendelt arcok",
    "_%n photos_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "Failed to fetch collection." : "A gyűjtemény lekérése sikertelen.",
    "Failed to fetch collections list." : "A gyűjtemények lekérése sikertelen.",
    "Failed to fetch faces list." : "Az arcok lekérése sikertelen.",
    "All your media" : "Összes saját média",
    "Album {title}" : "Album: {title}",
    "Shared Albums" : "Megosztott albumok",
    "Shared album {title}" : "Megosztott album: {title}",
    "Public album {title}" : "Nyilvános album: {title}",
    "Tagged photos" : "Címkézett fényképek",
    "Tagged photo {title}" : "Címkézett fénykép: {title}",
    "{title}'s face" : "{title} arca",
    "{startDate} to {endDate}" : "{startDate} – {endDate}",
    "Details" : "Részletek",
    "Failed to rename {oldName} to {faceName}." : "A(z) {oldName} átnevezése a következőre sikertelen: {faceName}.",
    "Failed to delete {faceName}." : "A(z) {faceName} törlése sikertelen.",
    "Failed to delete {fileId}." : "A(z) {fileId} törlése sikertelen.",
    "Failed to delete {fileName}." : "A(z) {fileName} törlése sikertelen.",
    "Failed to set favorite state for {fileId}." : "A(z) {fileId} kedvenc állapotának beállítása sikertelen.",
    "Failed to set favorite state for {fileName}." : "A(z) {fileName} kedvenc állapotának beállítása sikertelen.",
    "Could not load photos folder" : "Nem lehet a fotók könyvtárat betölteni",
    "One of the source folders does not exists" : "Az egyik forrás könyvtár nem létezik",
    "Add" : "Hozzáadás"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/hu.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Nyilvános hivatkozás",
    "Photos" : "Fényképek",
    "On This Day" : "Ezen a napon",
    "Your memories under your control" : "Az Ön emlékei, az Ön felügyelete alatt",
    "All media" : "Összes média",
    "Videos" : "Videók",
    "Albums" : "Albumok",
    "Collaborative albums" : "Közreműködőkkel készült albumok",
    "People" : "Emberek",
    "Folders" : "Mappák",
    "Favorites" : "Kedvencek",
    "On this day" : "A mai napon",
    "Shared with you" : "Megosztva Önnel",
    "Tags" : "Címkék",
    "Places" : "Helyek",
    "Map" : "Térkép",
    "Photos settings" : "Fényképek beállításai",
    "Mark selection as favorite" : "Kiválasztás megjelölése kedvencként",
    "Add selection to favorites" : "Kiválasztás hozzáadása a kedvencekhez",
    "Remove selection from favorites" : "Kiválasztás eltávolítása a kedvencek közül",
    "This name is already in use." : "Ez a név már foglalt.",
    "\"{char}\" is not allowed inside a filename." : "„{char}” nem szerepelhet a fájlnévben.",
    "Invalid filename." : "Érvénytelen fájlnév.",
    "Name of the album" : "Az album neve",
    "Location of the album" : "Az album helye",
    "Back" : "Vissza",
    "Add collaborators" : "Közreműködők hozzáadása",
    "Save" : "Mentés",
    "Create album" : "Album létrehozása",
    "Add to Album" : "Hozzáadás az albumhoz",
    "Add selection to album {albumName}" : "Kiválasztás hozzáadása a(z) {albumName} albumhoz",
    "Shared by" : "Megosztotta:",
    "Create a new album." : "Új album létrehozása.",
    "Create new album" : "Új album létrehozása",
    "New album" : "Új album",
    "_%n item_::_%n photos and videos_" : ["%n fénykép és videó","%n fénykép és videó"],
    "Failed to fetch collaborators list." : "A közreműködők lekérése sikertelen.",
    "Failed to update album." : "Az album frissítése sikertelen.",
    "Add people or groups who can edit your album" : "Emberek vagy csoportok hozzáadása, akik szerkeszthetik az albumot",
    "Search people or groups" : "Felhasználó vagy csoport keresése",
    "No recommendations. Start typing." : "Nincs javaslat. Kezdjen gépelni.",
    "Copy the public link" : "Nyilvános hivatkozás másolása",
    "Public link copied!" : "Nyilvános hivatkozás másolva.",
    "Copy public link" : "Nyilvános hivatkozás másolása",
    "Delete the public link" : "Nyilvános hivatkozás törlése",
    "Create public link share" : "Nyilvános hivatkozásos megosztás létrehozása",
    "Share via public link" : "Megosztva nyilvános hivatkozással",
    "This collection does not exist" : "Ez a gyűjtemény nem létezik",
    "An error occurred" : "Hiba történt",
    "No picture for this day" : "Nincs kép erre a napra",
    "Picture taken on this day will show up here." : "Ezen a napon a napon készült képek fognak itt megjelenni.",
    "More photos from this day" : "További képek erről a napról",
    "_%n photos_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nem hozzárendelt fénykép","%n nem hozzárendelt fénykép"],
    "Favorite" : "Kedvenc",
    "Favorite image, open the full size \"{name}\" image" : "Kedvenc kép, a \"{name}\" kép teljes méretben való megnyitása",
    "Open the full size \"{name}\" image" : "A teljes méretű „{name}” fénykép megnyitása",
    "Select image {imageName}" : "{imageName} kép kiválasztása",
    "Open the \"{name}\" folder" : "A \"{name}\" könyvtár megnyitása",
    "Go back" : "Visszalépés",
    "Dates" : "Dátumok",
    "Jump to specific date in list" : "Ugrás a listán egy megadott dátumhoz",
    "Jump to {date}" : "Ugrás ekorra {date}",
    "Add to {destination}" : "Hozzáadás ehhez: {destination}",
    "The destination folder is owned by {owner}" : "A célmappa {owner}tulajdonában van",
    "There are no photos or videos yet!" : "Még nincs fénykép vagy videó.",
    "_{years} year ago_::_{years} years ago_" : ["{years} éve","{years} éve"],
    "Delete source directory" : "A forrás könyvtár törlése",
    "Select a source folder for your media" : "Válaszd ki a könyvtárat a médiád számára",
    "Media folders" : "Média könyvtárak",
    "Choose the folders from where photos and videos are shown." : "Válassz egy könyvtárat ahonnan a fotók és videók megjelennek.",
    "All folders" : "Összes könyvtár",
    "Add a Photos source for the timelines" : "Fotó forrás hozzáadása az idővonalakhoz",
    "Add folder" : "Könyvtár hozzáadása",
    "Home" : "Kezdőlap",
    "Select the default upload location for your media" : "Válaszd ki a alapvető feltöltési helyet a médiáid számára",
    "Upload folder" : "Feltöltési könyvtár",
    "General" : "Általános",
    "_%n photo_::_%n photos_" : ["%n fénykép","%n fénykép"],
    "Unselect all" : "Kijelölés megszüntetése",
    "Add photos to this album" : "Fényképek hozzáadása az albumhoz",
    "Manage collaborators for this album" : "Az album közreműködőinek kezelése",
    "Open actions menu" : "Műveletek menü megnyitása",
    "Edit album details" : "Album részleteinek szerkesztése",
    "Download all files in album" : "Összes fájl letöltése az albumből",
    "Delete album" : "Album törlése",
    "Download selected files" : "Kiválasztott fájlok letöltése",
    "Remove selection from album" : "Kiválasztás eltávolítása az albumból",
    "This album does not have any photos or videos yet!" : "Még nincs fénykép vagy videó ebben az albumban.",
    "Add photos to {albumName}" : "Fényképek hozzáadása a(z) {albumName} albumhoz",
    "Manage collaborators" : "Közreműködők kezelése",
    "Save collaborators for this album." : "Közreműködők mentése ehhez az albumhoz.",
    "Cover photo for album {albumName}" : "Borítókép a(z) „{albumName}” albumhoz",
    "There is no album yet!" : "Még nincs album.",
    "This person could not be found" : "Ez a személy nem található",
    "Rename person" : "Személy átnevezése",
    "Merge with different person" : "Összevonás egy másik személlyel",
    "Download selected photos" : "Kiválasztott fényképek letöltése",
    "Remove from favorites" : "Eltávolítás a kedvencek közül",
    "Remove person" : "Személy eltávolítása",
    "Name of this person" : "A személy neve",
    "Save." : "Mentés.",
    "Merge person" : "Személy egyesítése",
    "Move to different person" : "Áthelyezés egy másik személyhez",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Fénykép áthelyezése egy másik személyhez","Fényképek áthelyezése egy másik személyhez"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fénykép eltávolítása a személytől","Fényképek eltávolítása a személytől"],
    "This might take some time depending on the size of your photo library." : "Ez a fényképkönyvtár méretétől függően eltarthat egy darabig.",
    "Recognized people will show up here" : "A felismert emberek itt fognak megjelenni",
    "This folder does not exist" : "Ez a mappa nem létezik",
    "Loading folders…" : "Mappák betöltése…",
    "No photos in here" : "Itt nincsenek fényképek",
    "Taken on {date} at {time}" : "Fényképezve {date}-án {time}-kor",
    "This place does not have any photos or videos yet!" : "Ehhez a helyhez még nincs fénykép vagy videó.",
    "Add photos to this place" : "Fényképek hozzáadása ehhez a helyhez",
    "Cover photo for place {placeName}" : "A következő hely borítóképe: {placeName}",
    "There is no place yet!" : "Még nincsenek helyek.",
    "Back to tags overview" : "Vissza a címkeáttekintőhöz",
    "No photos with this tag yet" : "Még nincsenek fényképek ezzel a címkével",
    "No tags yet" : "Még nincsenek címkék",
    "Photos with tags will show up here" : "A címkével rendelkező fényképek itt fognak megjelenni",
    "Popular tags" : "Népszerű címkék",
    "All tags" : "Összes jelölés",
    "One of the source folders does not exist" : "Az egyik forrás könyvtár nem létezik",
    "Add to album" : "Hozzáadás az albumhoz",
    "Delete selection" : "Kiválasztás törlése",
    "No photos or videos in here" : "Itt nincs fénykép vagy videó",
    "Unassigned faces" : "Nem hozzárendelt arcok",
    "Failed to fetch collection." : "A gyűjtemény lekérése sikertelen.",
    "Failed to fetch collections list." : "A gyűjtemények lekérése sikertelen.",
    "Failed to fetch faces list." : "Az arcok lekérése sikertelen.",
    "All your media" : "Összes saját média",
    "Album {title}" : "Album: {title}",
    "Shared Albums" : "Megosztott albumok",
    "Shared album {title}" : "Megosztott album: {title}",
    "Public album {title}" : "Nyilvános album: {title}",
    "Tagged photos" : "Címkézett fényképek",
    "Tagged photo {title}" : "Címkézett fénykép: {title}",
    "{title}'s face" : "{title} arca",
    "Last week" : "Előző hét",
    "{startDate} to {endDate}" : "{startDate} – {endDate}",
    "Details" : "Részletek",
    "Cancel" : "Cancel",
    "Confirm" : "Megerősítés",
    "Could not load photos folder" : "Nem lehet a fotók könyvtárat betölteni",
    "Group" : "Csoport",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} eltávolítása a közreműködőktől",
    "Back to {folder}" : "Vissza ide: {folder}",
    "Share this folder" : "Mappa megosztása",
    "Enable squared photos view" : "A négyzet alakú fotónézet engedélyezése",
    "Choose default Photos upload and Albums location" : "A Fényképfeltöltés és az Albumok alapértelmezett helyének kiválasztása",
    "Choose a different folder" : "Válassz másik könyvtárat",
    "View" : "Megtekintés",
    "Choose the folder where photos and albums are uploaded to." : "Válassz másik könyvtárat a fotók és albumok feltöltése számára.",
    "Loading folders …" : "Mappák betöltése…",
    "Add" : "Hozzáadás"
},
"nplurals=2; plural=(n != 1);");
